
From: Mikael Pettersson <mikpe@csd.uu.se>

The inclusion of the pselect6 and ppoll syscalls in 2.6.12-mm2 broke ia32
emulation on x86_64, and ppc32 emulation on ppc64, for the perfctr
syscalls.  This patch fixes this, and also corrects a few comments in the
ppc32 syscall tables.

Signed-off-by: Mikael Pettersson <mikpe@csd.uu.se>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 ppc/kernel/misc.S                |    0 
 arch/ppc64/kernel/misc.S         |    4 ++++
 arch/x86_64/ia32/ia32entry.S     |    4 +++-
 include/asm-x86_64/ia32_unistd.h |    4 ++--
 4 files changed, 9 insertions(+), 3 deletions(-)

diff -puN arch/ppc64/kernel/misc.S~perfctr-syscall-numbering-fixups arch/ppc64/kernel/misc.S
--- devel/arch/ppc64/kernel/misc.S~perfctr-syscall-numbering-fixups	2005-07-16 13:57:22.000000000 -0700
+++ devel-akpm/arch/ppc64/kernel/misc.S	2005-07-16 13:57:22.000000000 -0700
@@ -1131,6 +1131,10 @@ _GLOBAL(sys_call_table32)
 	.llong .sys32_ioprio_get
 	.llong .compat_sys_pselect6	/* 275 */
 	.llong .compat_sys_ppoll
+	.llong .sys_vperfctr_open
+	.llong .sys_vperfctr_control
+	.llong .sys_vperfctr_write
+	.llong .sys_vperfctr_read	/* 280 */
 
 	.balign 8
 _GLOBAL(sys_call_table)
diff -puN arch/ppc/kernel/misc.S~perfctr-syscall-numbering-fixups arch/ppc/kernel/misc.S
diff -puN arch/x86_64/ia32/ia32entry.S~perfctr-syscall-numbering-fixups arch/x86_64/ia32/ia32entry.S
--- devel/arch/x86_64/ia32/ia32entry.S~perfctr-syscall-numbering-fixups	2005-07-16 13:57:22.000000000 -0700
+++ devel-akpm/arch/x86_64/ia32/ia32entry.S	2005-07-16 13:58:34.000000000 -0700
@@ -591,8 +591,10 @@ ia32_sys_call_table:
 	.quad sys_inotify_init
 	.quad sys_inotify_add_watch
 	.quad sys_inotify_rm_watch
+	.quad quiet_ni_syscall		/* pselect6 */
+	.quad quiet_ni_syscall		/* ppoll 295 */
 	.quad sys_vperfctr_open
-	.quad sys_vperfctr_control	/* 295 */
+	.quad sys_vperfctr_control
 	.quad sys_vperfctr_write
 	.quad sys_vperfctr_read
 ia32_syscall_end:		
diff -puN include/asm-x86_64/ia32_unistd.h~perfctr-syscall-numbering-fixups include/asm-x86_64/ia32_unistd.h
--- devel/include/asm-x86_64/ia32_unistd.h~perfctr-syscall-numbering-fixups	2005-07-16 13:57:22.000000000 -0700
+++ devel-akpm/include/asm-x86_64/ia32_unistd.h	2005-07-16 13:59:47.000000000 -0700
@@ -299,11 +299,11 @@
 #define __NR_ia32_inotify_init		291
 #define __NR_ia32_inotify_add_watch	292
 #define __NR_ia32_inotify_rm_watch	293
-#define __NR_ia32_vperfctr_open		294
+#define __NR_ia32_vperfctr_open		296
 #define __NR_ia32_vperfctr_control	(__NR_ia32_vperfctr_open+1)
 #define __NR_ia32_vperfctr_write	(__NR_ia32_vperfctr_open+2)
 #define __NR_ia32_vperfctr_read		(__NR_ia32_vperfctr_open+3)
 
-#define IA32_NR_syscalls 298	/* must be > than biggest syscall! */
+#define IA32_NR_syscalls 300	/* must be > than biggest syscall! */
 
 #endif /* _ASM_X86_64_IA32_UNISTD_H_ */
_
